@@ -82,7 +82,9 @@ read10xVisiumSFE <- function(samples = deprecated(),
     data <- match.arg(data)
     unit <- match.arg(unit)
     flip <- match.arg(flip)
-    if (.terra_flip()) flip <- "none"
+    if (packageVersion('terra') == as.package_version("1.7.83") ||
+        packageVersion('terra') >= as.package_version("1.8.10"))
+        flip <- "none"
     images <- match.arg(images, several.ok = TRUE)
     row.names <- match.arg(row.names)
     enrichment_feature <- switch(row.names,
@@ -322,7 +324,9 @@ readVisiumHD <- function(data_dir, bin_size = c(2L, 8L, 16L),
     data <- match.arg(data)
     unit <- match.arg(unit)
     flip <- match.arg(flip)
-    if (.terra_flip()) flip <- "none"
+    if (packageVersion('terra') == as.package_version("1.7.83") ||
+        packageVersion('terra') >= as.package_version("1.8.10"))
+        flip <- "none"
     images <- match.arg(images, several.ok = TRUE)
     bin_size <- match.arg(as.character(bin_size), choices = c("2", "8", "16"),
                           several.ok = TRUE) |> 
@@ -732,7 +736,9 @@ readVizgen <- function(data_dir,
     check_installed("sfarrow")
     data_dir <- normalizePath(data_dir, mustWork = TRUE)
     flip <- match.arg(flip)
-    if (.terra_flip()) flip <- "none"
+    if (packageVersion('terra') == as.package_version("1.7.83") ||
+        packageVersion('terra') >= as.package_version("1.8.10"))
+        flip <- "none"
     image <- match.arg(image, several.ok = TRUE)
     if ((any(z < 0) || any(z > 6)) && z != "all") {
         stop("z must be beween 0 and 6 (inclusive).")
