@@ -19,7 +19,7 @@ sp_enr2 <- read.csv(file.path(outdir, "sample02", "outs", "spatial",
 pos2 <- read.csv(file.path(outdir, "sample02", "outs", "spatial",
                            "tissue_positions.csv"))
 
-samples <- file.path(outdir, paste0("sample0", 1:2))
+samples <- file.path(outdir, paste0("sample0", 1:2), "outs")
 
 rd1 <- sp_enr1[,4:9]
 rd2 <- sp_enr2[,4:9]
@@ -31,7 +31,7 @@ rd_expect <- cbind(Feature.Type = sp_enr1$Feature.Type, rd1, rd2)
 cd_expect <- rbind(bc_flou1, bc_flou2)[, 3:8]
 
 test_that("Correctly read Space Ranger output", {
-    sfe <- read10xVisiumSFE(samples, type = "sparse", data = "filtered")
+    sfe <- read10xVisiumSFE(dirs = samples, type = "sparse", data = "filtered")
     # Very basic one
     expect_s4_class(sfe, "SpatialFeatureExperiment")
     expect_equal(sampleIDs(sfe), c("sample01", "sample02"))
@@ -45,33 +45,33 @@ test_that("Correctly read Space Ranger output", {
 })
 
 test_that("Correctly add visium graph when there's 1 sample", {
-    sfe <- read10xVisiumSFE(samples[1], type = "sparse", data = "filtered")
+    sfe <- read10xVisiumSFE(dirs = samples[1], type = "sparse", data = "filtered")
     expect_equal(colGraphNames(sfe, "sample01"), "visium")
 })
 
 # Need uncropped image
-if (!dir.exists("ob")) dir.create(file.path("ob", "outs"), recursive = TRUE)
-mat_fn <- file.path("ob", "outs", "filtered_feature_bc_matrix.h5")
+if (!dir.exists("ob")) dir.create("ob", recursive = TRUE)
+mat_fn <- file.path("ob", "filtered_feature_bc_matrix.h5")
 if (!file.exists(mat_fn))
     download.file("https://cf.10xgenomics.com/samples/spatial-exp/2.0.0/Visium_Mouse_Olfactory_Bulb/Visium_Mouse_Olfactory_Bulb_filtered_feature_bc_matrix.h5",
-                  destfile = file.path("ob", "outs", "filtered_feature_bc_matrix.h5"),
+                  destfile = file.path("ob", "filtered_feature_bc_matrix.h5"),
                   mode = "wb")
-if (!dir.exists(file.path("ob", "outs", "spatial"))) {
+if (!dir.exists(file.path("ob", "spatial"))) {
     download.file("https://cf.10xgenomics.com/samples/spatial-exp/2.0.0/Visium_Mouse_Olfactory_Bulb/Visium_Mouse_Olfactory_Bulb_spatial.tar.gz",
-                  destfile = file.path("ob", "outs", "spatial.tar.gz"))
-    untar(file.path("ob", "outs", "spatial.tar.gz"), exdir = file.path("ob", "outs"))
+                  destfile = file.path("ob", "spatial.tar.gz"))
+    untar(file.path("ob", "spatial.tar.gz"), exdir = "ob")
 }
 
-if (!dir.exists("kidney")) dir.create(file.path("kidney", "outs"), recursive = TRUE)
-mat_fn <- file.path("kidney", "outs", "filtered_feature_bc_matrix.h5")
+if (!dir.exists("kidney")) dir.create("kidney", recursive = TRUE)
+mat_fn <- file.path("kidney", "filtered_feature_bc_matrix.h5")
 if (!file.exists(mat_fn))
     download.file("https://cf.10xgenomics.com/samples/spatial-exp/1.0.0/V1_Mouse_Kidney/V1_Mouse_Kidney_filtered_feature_bc_matrix.h5",
-                  destfile = file.path("kidney", "outs", "filtered_feature_bc_matrix.h5"),
+                  destfile = file.path("kidney", "filtered_feature_bc_matrix.h5"),
                   mode = "wb")
-if (!dir.exists(file.path("kidney", "outs", "spatial"))) {
+if (!dir.exists(file.path("kidney", "spatial"))) {
     download.file("https://cf.10xgenomics.com/samples/spatial-exp/1.0.0/V1_Mouse_Kidney/V1_Mouse_Kidney_spatial.tar.gz",
-                  destfile = file.path("kidney", "outs", "spatial.tar.gz"))
-    untar(file.path("kidney", "outs", "spatial.tar.gz"), exdir = file.path("kidney", "outs"))
+                  destfile = file.path("kidney", "spatial.tar.gz"))
+    untar(file.path("kidney", "spatial.tar.gz"), exdir = "kidney")
 }
 
 library(terra)
@@ -80,7 +80,7 @@ library(SingleCellExperiment)
 library(SpatialExperiment)
 
 test_that("Image is properly aligned in pixel space", {
-    sfe <- read10xVisiumSFE("ob")
+    sfe <- read10xVisiumSFE(dirs = "ob")
     expect_equal(unit(sfe), "full_res_image_pixel")
     cg <- spotPoly(sfe)
     cg$nCounts <- Matrix::colSums(counts(sfe))
@@ -103,22 +103,22 @@ test_that("Image is properly aligned in pixel space", {
 })
 
 test_that("Read when one out of multiple images are desired", {
-    sfe <- read10xVisiumSFE("ob", images = "lowres")
+    sfe <- read10xVisiumSFE(dirs = "ob", images = "lowres")
     expect_equal(nrow(imgData(sfe)), 1L)
     expect_equal(imgData(sfe)$image_id, "lowres")
 })
 
 test_that("Image is properly aligned in micron space", {
-    sfe <- read10xVisiumSFE("ob", unit = "micron")
+    sfe <- read10xVisiumSFE(dirs = "ob", unit = "micron")
     expect_equal(unit(sfe), "micron")
     cg <- spotPoly(sfe)
     cg$nCounts <- Matrix::colSums(counts(sfe))
     cg$geometry <- st_centroid(cg$geometry)
-    img_lo <- getImg(sfe, image_id = "lowres") |> imgRaster()
+    img_lo <- getImg(sfe, image_id = "lowres")
     img_lo <- terra::mean(img_lo)
     v_lo <- terra::extract(img_lo, cg)
     expect_true(abs(cor(cg$nCounts, v_lo$mean)) > 0.4)
-    img_hi <- getImg(sfe, image_id = "hires") |> imgRaster()
+    img_hi <- getImg(sfe, image_id = "hires")
     img_hi <- terra::mean(img_hi)
     v_hi <- terra::extract(img_hi, cg)
     expect_true(abs(cor(cg$nCounts, v_hi$mean)) > 0.4)
@@ -133,7 +133,7 @@ test_that("Image is properly aligned in micron space", {
 })
 
 test_that("Micron spot spacing works when there're singletons", {
-    sfe <- read10xVisiumSFE("kidney", unit = "micron", zero.policy = TRUE)
+    sfe <- read10xVisiumSFE(dirs = "kidney", unit = "micron", zero.policy = TRUE)
     expect_equal(unit(sfe), "micron")
 })
 
@@ -202,7 +202,7 @@ test_that("readVizgen flip geometry, use cellpose", {
     expect_equal(imgData(sfe)$image_id,
                  paste0(c(paste0("Cellbound", 1:3), "DAPI", "PolyT"),
                        "_z3"))
-    img <- imgRaster(getImg(sfe, image_id = "PolyT_z3"))
+    img <- getImg(sfe, image_id = "PolyT_z3")
     cg <- SpatialFeatureExperiment::centroids(sfe)
     v <- terra::extract(img, cg)
     # Shouldn't be many cells in that empty space if properly aligned
@@ -243,7 +243,7 @@ test_that("readVizgen flip geometry, don't use cellpose", {
     sfe <- readVizgen(dir_use, z = 3L, use_cellpose = FALSE, image = "PolyT",
                       flip = "geometry")
     expect_equal(unit(sfe), "micron")
-    img <- imgRaster(getImg(sfe))
+    img <- getImg(sfe)
     cg <- SpatialFeatureExperiment::centroids(sfe)
     v <- terra::extract(img, cg)
     expect_true(sum(v$mosaic_PolyT_z3 < 30, na.rm = TRUE) < 10)
@@ -267,7 +267,7 @@ test_that("readVizgen flip image", {
     sfe <- readVizgen(dir_use, z = 3L, use_cellpose = FALSE, image = "PolyT",
                       flip = "image")
     expect_equal(unit(sfe), "micron")
-    img <- imgRaster(getImg(sfe))
+    img <- getImg(sfe)
     cg <- SpatialFeatureExperiment::centroids(sfe)
     v <- terra::extract(img, cg)
     expect_true(sum(v$mosaic_PolyT_z3 < 30, na.rm = TRUE) < 10)
@@ -279,11 +279,11 @@ test_that("readVizgen don't flip image when image is too large", {
     dir_use <- VizgenOutput("hdf5", file_path = fp)
     expect_error(readVizgen(dir_use, z = 3L, use_cellpose = FALSE, image = "PolyT",
                             flip = "image", max_flip = "0.02 TB"),
-                 "max_flip must be in either MB or GB")
+                 "must be in either MB or GB")
     sfe <- readVizgen(dir_use, z = 3L, use_cellpose = FALSE, image = "PolyT",
                       flip = "image", max_flip = "0.02 MB")
     suppressWarnings(img_orig <- rast(file.path(dir_use, "images", "mosaic_PolyT_z3.tif")))
-    img <- imgRaster(getImg(sfe))
+    img <- getImg(sfe)
     # Make sure image was not flipped
     expect_equal(terra::values(img), terra::values(img_orig))
     cg <- SpatialFeatureExperiment::centroids(sfe)
@@ -297,12 +297,12 @@ test_that("Don't flip image if it's GeoTIFF", {
     dir_use <- VizgenOutput("hdf5", file_path = fp)
     sfe <- readVizgen(dir_use, z = 3L, use_cellpose = FALSE, image = "PolyT",
                       flip = "image")
-    terra::writeRaster(imgRaster(getImg(sfe)),
+    terra::writeRaster(getImg(sfe),
                        filename = file.path(dir_use, "images", "mosaic_DAPI_z3.tif"),
                        overwrite = TRUE)
     sfe2 <- readVizgen(dir_use, z = 3L, use_cellpose = FALSE, image = "DAPI",
                        flip = "image")
-    expect_equal(terra::values(imgRaster(getImg(sfe))), terra::values(imgRaster(getImg(sfe2))))
+    expect_equal(terra::values(getImg(sfe)), terra::values(getImg(sfe2)))
     unlink(dir_use, recursive = TRUE)
 })
 
@@ -395,7 +395,7 @@ test_that("Version with Cellpose directory", {
     expect_equal(imgData(sfe)$image_id,
                  paste0(c(paste0("Cellbound", 1:3), "DAPI", "PolyT"),
                         "_z3"))
-    img <- imgRaster(getImg(sfe, image_id = "PolyT_z3"))
+    img <- getImg(sfe, image_id = "PolyT_z3")
     cg <- SpatialFeatureExperiment::centroids(sfe)
     v <- terra::extract(img, cg)
     # Shouldn't be many cells in that empty space if properly aligned
@@ -494,6 +494,13 @@ test_that("readCosMX, not reading transcript spots", {
     unlink(dir_use, recursive = TRUE)
 })
 
+test_that("readCosMX, set sample_id", {
+    fp <- tempfile()
+    dir_use <- CosMXOutput(file_path = fp)
+    sfe <- readCosMX(dir_use, z = 1L, sample_id = "foo")
+    expect_equal(sampleIDs(sfe), "foo")
+})
+
 test_that("readCosMX, reading spots, 1 z-plane", {
     fp <- tempfile()
     dir_use <- CosMXOutput(file_path = fp)
